@@ -1,4 +1,4 @@
-# Copyright (C) 2011-2016 2ndQuadrant Italia Srl
+# Copyright (C) 2011-2017 2ndQuadrant Limited
 #
 # This file is part of Barman.
 #
@@ -96,7 +96,7 @@ class CsvOption(set):
         Parses a list of values and correctly assign the set of values
         (removing duplication) and checking for conflicts.
         """
-        if value == '':
+        if not value:
             return
         values_list = value.split(',')
         for val in sorted(values_list):
@@ -142,26 +142,15 @@ class BackupOptions(CsvOption):
     # constants containing labels for allowed values
     EXCLUSIVE_BACKUP = 'exclusive_backup'
     CONCURRENT_BACKUP = 'concurrent_backup'
+    EXTERNAL_CONFIGURATION = 'external_configuration'
 
     # list holding all the allowed values for the BackupOption class
-    value_list = [EXCLUSIVE_BACKUP, CONCURRENT_BACKUP]
+    value_list = [EXCLUSIVE_BACKUP, CONCURRENT_BACKUP, EXTERNAL_CONFIGURATION]
     # map holding all the possible conflicts between the allowed values
     conflicts = {
         EXCLUSIVE_BACKUP: CONCURRENT_BACKUP,
         CONCURRENT_BACKUP: EXCLUSIVE_BACKUP, }
 
-    def validate(self, key, source):
-        """
-        Validates backup_option values: currently it makes sure
-        that either exclusive_backup or concurrent_backup are set.
-        """
-        if self.CONCURRENT_BACKUP not in self \
-                and self.EXCLUSIVE_BACKUP not in self:
-            raise ValueError("Invalid configuration value for "
-                             "key %s in %s: it must contain either "
-                             "exclusive_backup or concurrent_backup option"
-                             % (key, source))
-
 
 class RecoveryOptions(CsvOption):
     """
@@ -266,6 +255,7 @@ class ServerConfig(object):
     KEYS = [
         'active',
         'archiver',
+        'archiver_batch_size',
         'backup_directory',
         'backup_method',
         'backup_options',
@@ -273,6 +263,7 @@ class ServerConfig(object):
         'basebackup_retry_sleep',
         'basebackup_retry_times',
         'basebackups_directory',
+        'check_timeout',
         'compression',
         'conninfo',
         'custom_compression_filter',
@@ -283,8 +274,10 @@ class ServerConfig(object):
         'immediate_checkpoint',
         'incoming_wals_directory',
         'last_backup_maximum_age',
+        'max_incoming_wals_queue',
         'minimum_redundancy',
         'network_compression',
+        'parallel_jobs',
         'path_prefix',
         'post_archive_retry_script',
         'post_archive_script',
@@ -298,8 +291,12 @@ class ServerConfig(object):
         'retention_policy',
         'retention_policy_mode',
         'reuse_backup',
+        'slot_name',
         'ssh_command',
         'streaming_archiver',
+        'streaming_archiver_batch_size',
+        'streaming_archiver_name',
+        'streaming_backup_name',
         'streaming_conninfo',
         'streaming_wals_directory',
         'tablespace_bandwidth_limit',
@@ -309,52 +306,70 @@ class ServerConfig(object):
 
     BARMAN_KEYS = [
         'archiver',
+        'archiver_batch_size',
         'backup_method',
         'backup_options',
         'bandwidth_limit',
         'basebackup_retry_sleep',
         'basebackup_retry_times',
+        'check_timeout',
         'compression',
         'configuration_files_directory',
         'custom_compression_filter',
         'custom_decompression_filter',
         'immediate_checkpoint',
         'last_backup_maximum_age',
+        'max_incoming_wals_queue',
         'minimum_redundancy',
         'network_compression',
+        'parallel_jobs',
         'path_prefix',
+        'post_archive_retry_script',
         'post_archive_script',
+        'post_backup_retry_script',
         'post_backup_script',
+        'pre_archive_retry_script',
         'pre_archive_script',
+        'pre_backup_retry_script',
         'pre_backup_script',
         'recovery_options',
         'retention_policy',
         'retention_policy_mode',
         'reuse_backup',
+        'slot_name',
         'streaming_archiver',
+        'streaming_archiver_batch_size',
+        'streaming_archiver_name',
+        'streaming_backup_name',
         'tablespace_bandwidth_limit',
         'wal_retention_policy'
     ]
 
     DEFAULTS = {
         'active': 'true',
-        'archiver': 'on',
+        'archiver': 'off',
+        'archiver_batch_size': '0',
         'backup_directory': '%(barman_home)s/%(name)s',
         'backup_method': 'rsync',
-        'backup_options': "%s" % BackupOptions.EXCLUSIVE_BACKUP,
+        'backup_options': '',
         'basebackup_retry_sleep': '30',
         'basebackup_retry_times': '0',
         'basebackups_directory': '%(backup_directory)s/base',
+        'check_timeout': '30',
         'disabled': 'false',
         'errors_directory': '%(backup_directory)s/errors',
         'immediate_checkpoint': 'false',
         'incoming_wals_directory': '%(backup_directory)s/incoming',
         'minimum_redundancy': '0',
         'network_compression': 'false',
+        'parallel_jobs': '1',
         'recovery_options': '',
         'retention_policy_mode': 'auto',
-        'streaming_conninfo': '%(conninfo)s',
         'streaming_archiver': 'off',
+        'streaming_archiver_batch_size': '0',
+        'streaming_archiver_name': 'barman_receive_wal',
+        'streaming_backup_name': 'barman_streaming_backup',
+        'streaming_conninfo': '%(conninfo)s',
         'streaming_wals_directory': '%(backup_directory)s/streaming',
         'wal_retention_policy': 'main',
         'wals_directory': '%(backup_directory)s/wals'
@@ -367,17 +382,22 @@ class ServerConfig(object):
     PARSERS = {
         'active': parse_boolean,
         'archiver': parse_boolean,
+        'archiver_batch_size': int,
         'backup_method': parse_backup_method,
         'backup_options': BackupOptions,
         'basebackup_retry_sleep': int,
         'basebackup_retry_times': int,
+        'check_timeout': int,
         'disabled': parse_boolean,
         'immediate_checkpoint': parse_boolean,
         'last_backup_maximum_age': parse_time_interval,
+        'max_incoming_wals_queue': int,
         'network_compression': parse_boolean,
+        'parallel_jobs': int,
         'recovery_options': RecoveryOptions,
         'reuse_backup': parse_reuse_backup,
         'streaming_archiver': parse_boolean,
+        'streaming_archiver_batch_size': int,
     }
 
     def invoke_parser(self, key, source, value, new_value):
@@ -415,10 +435,9 @@ class ServerConfig(object):
                 else:
                     value = parser(new_value)
             except Exception as e:
-                output.warning("Invalid configuration value '%s' for key %s"
-                               " in %s: %s",
-                               value, key, source, e)
-                _logger.exception(e)
+                output.warning("Ignoring invalid configuration value '%s' "
+                               "for key %s in %s: %s",
+                               new_value, key, source, e)
         else:
             value = new_value
         return value
@@ -470,6 +489,27 @@ class ServerConfig(object):
         del json_dict['config']
         return json_dict
 
+    def get_bwlimit(self, tablespace=None):
+        """
+        Return the configured bandwidth limit for the provided tablespace
+
+        If tablespace is None, it returns the global bandwidth limit
+
+        :param barman.infofile.Tablespace tablespace: the tablespace to copy
+        :rtype: str
+        """
+        # Default to global bandwidth limit
+        bwlimit = self.bandwidth_limit
+
+        if tablespace:
+            # A tablespace can be copied using a per-tablespace bwlimit
+            tablespaces_bw_limit = self.tablespace_bandwidth_limit
+            if (tablespaces_bw_limit and
+                    tablespace.name in tablespaces_bw_limit):
+                bwlimit = tablespaces_bw_limit[tablespace.name]
+
+        return bwlimit
+
 
 class Config(object):
     """This class represents the barman configuration.
