@@ -522,9 +522,10 @@ class PostgreSQLConnection(PostgreSQL):
             if not self.is_in_recovery:
                 cur.execute(
                     "SELECT location, "
-                    "(pg_xlogfile_name_offset(location)).*, "
+                    "({pg_walfile_name_offset}(location)).*, "
                     "CURRENT_TIMESTAMP AS timestamp "
-                    "FROM pg_current_xlog_location() AS location")
+                    "FROM {pg_current_wal_lsn}() AS location"
+                    .format(**self.name_map))
                 return cur.fetchone()
             else:
                 cur.execute(
@@ -532,7 +533,8 @@ class PostgreSQLConnection(PostgreSQL):
                     "NULL AS file_name, "
                     "NULL AS file_offset, "
                     "CURRENT_TIMESTAMP AS timestamp "
-                    "FROM pg_last_xlog_replay_location() AS location")
+                    "FROM {pg_last_wal_replay_lsn}() AS location"
+                    .format(**self.name_map))
                 return cur.fetchone()
         except (PostgresConnectionError, psycopg2.Error) as e:
             _logger.debug("Error retrieving current xlog "
@@ -682,6 +684,7 @@ class PostgreSQLConnection(PostgreSQL):
         pg_query_keys = [
             'server_txt_version',
             'is_superuser',
+            'is_in_recovery',
             'current_xlog',
             'pgespresso_installed',
             'replication_slot_support',
@@ -708,6 +711,7 @@ class PostgreSQLConnection(PostgreSQL):
                 result[name] = self.get_setting(name)
 
             result['is_superuser'] = self.is_superuser
+            result['is_in_recovery'] = self.is_in_recovery
             result['server_txt_version'] = self.server_txt_version
             result['pgespresso_installed'] = self.has_pgespresso
             result['current_xlog'] = self.current_xlog_file_name
@@ -873,16 +877,18 @@ class PostgreSQLConnection(PostgreSQL):
             if self.server_version < 80400:
                 cur.execute(
                     "SELECT location, "
-                    "(pg_xlogfile_name_offset(location)).*, "
+                    "({pg_walfile_name_offset}(location)).*, "
                     "now() AS timestamp "
-                    "FROM pg_start_backup(%s) AS location",
+                    "FROM pg_start_backup(%s) AS location"
+                    .format(**self.name_map),
                     (label,))
             else:
                 cur.execute(
                     "SELECT location, "
-                    "(pg_xlogfile_name_offset(location)).*, "
+                    "({pg_walfile_name_offset}(location)).*, "
                     "now() AS timestamp "
-                    "FROM pg_start_backup(%s,%s) AS location",
+                    "FROM pg_start_backup(%s,%s) AS location"
+                    .format(**self.name_map),
                     (label, self.config.immediate_checkpoint))
 
             start_row = cur.fetchone()
@@ -963,9 +969,11 @@ class PostgreSQLConnection(PostgreSQL):
             cur = conn.cursor(cursor_factory=DictCursor)
             cur.execute(
                 "SELECT location, "
-                "(pg_xlogfile_name_offset(location)).*, "
+                "({pg_walfile_name_offset}(location)).*, "
                 "now() AS timestamp "
-                "FROM pg_stop_backup() AS location")
+                "FROM pg_stop_backup() AS location"
+                .format(**self.name_map)
+            )
 
             return cur.fetchone()
         except (PostgresConnectionError, psycopg2.Error) as e:
@@ -1085,9 +1093,9 @@ class PostgreSQLConnection(PostgreSQL):
                 'pgespresso_abort_backup() on your PostgreSQL '
                 'server' % msg)
 
-    def switch_xlog(self):
+    def switch_wal(self):
         """
-        Execute a pg_switch_xlog()
+        Execute a pg_switch_wal()
 
         To be SURE of the switch of a xlog, we collect the xlogfile name
         before and after the switch.
@@ -1095,7 +1103,7 @@ class PostgreSQLConnection(PostgreSQL):
         file has changed, it returns an empty string otherwise.
 
         The method returns None if something went wrong during the execution
-        of the pg_switch_xlog command.
+        of the pg_switch_wal command.
 
         :rtype: str|None
         """
@@ -1111,14 +1119,17 @@ class PostgreSQLConnection(PostgreSQL):
 
             cur = conn.cursor()
             # Collect the xlog file name before the switch
-            cur.execute('SELECT pg_xlogfile_name('
-                        'pg_current_xlog_insert_location())')
+            cur.execute('SELECT {pg_walfile_name}('
+                        '{pg_current_wal_insert_lsn}())'
+                        .format(**self.name_map))
             pre_switch = cur.fetchone()[0]
             # Switch
-            cur.execute('SELECT pg_xlogfile_name(pg_switch_xlog())')
+            cur.execute('SELECT {pg_walfile_name}({pg_switch_wal}())'
+                        .format(**self.name_map))
             # Collect the xlog file name after the switch
-            cur.execute('SELECT pg_xlogfile_name('
-                        'pg_current_xlog_insert_location())')
+            cur.execute('SELECT {pg_walfile_name}('
+                        '{pg_current_wal_insert_lsn}())'
+                        .format(**self.name_map))
             post_switch = cur.fetchone()[0]
             if pre_switch < post_switch:
                 return pre_switch
@@ -1126,7 +1137,8 @@ class PostgreSQLConnection(PostgreSQL):
                 return ''
         except (PostgresConnectionError, psycopg2.Error) as e:
             _logger.debug(
-                "Error issuing pg_switch_xlog() command: %s",
+                "Error issuing {pg_switch_wal}() command: %s"
+                .format(**self.name_map),
                 str(e).strip())
             return None
 
@@ -1175,10 +1187,10 @@ class PostgreSQLConnection(PostgreSQL):
             # - backend_start
             # - backend_xmin (9.4+)
             # - state
-            # - sent_location
-            # - write_location
-            # - flush_location
-            # - replay_location
+            # - sent_lsn (sent_location before 10)
+            # - write_lsn (write_location before 10)
+            # - flush_lsn (flush_location before 10)
+            # - replay_lsn (replay_location before 10)
             # - sync_priority
             # - sync_state
             #
@@ -1187,76 +1199,115 @@ class PostgreSQLConnection(PostgreSQL):
                 raise PostgresUnsupportedFeature('9.1')
 
             from_repslot = ""
-            if self.server_version >= 90500:
-                # Current implementation (9.5+)
+            if self.server_version >= 100000:
+                # Current implementation (10+)
                 what = "r.*, rs.slot_name"
                 # Look for replication slot name
                 from_repslot = "LEFT JOIN pg_replication_slots rs " \
                                "ON (r.pid = rs.active_pid) "
+            elif self.server_version >= 90500:
+                # PostgreSQL 9.5/9.6
+                what = "pid, " \
+                    "usesysid, " \
+                    "usename, " \
+                    "application_name, " \
+                    "client_addr, " \
+                    "client_hostname, " \
+                    "client_port, " \
+                    "backend_start, " \
+                    "backend_xmin, " \
+                    "state, " \
+                    "sent_location AS sent_lsn, " \
+                    "write_location AS write_lsn, " \
+                    "flush_location AS flush_lsn, " \
+                    "replay_location AS replay_lsn, " \
+                    "sync_priority, " \
+                    "sync_state, " \
+                    "rs.slot_name"
+                # Look for replication slot name
+                from_repslot = "LEFT JOIN pg_replication_slots rs " \
+                               "ON (r.pid = rs.active_pid) "
             elif self.server_version >= 90400:
                 # PostgreSQL 9.4
-                what = "*"
+                what = "pid, " \
+                    "usesysid, " \
+                    "usename, " \
+                    "application_name, " \
+                    "client_addr, " \
+                    "client_hostname, " \
+                    "client_port, " \
+                    "backend_start, " \
+                    "backend_xmin, " \
+                    "state, " \
+                    "sent_location AS sent_lsn, " \
+                    "write_location AS write_lsn, " \
+                    "flush_location AS flush_lsn, " \
+                    "replay_location AS replay_lsn, " \
+                    "sync_priority, " \
+                    "sync_state"
             elif self.server_version >= 90200:
                 # PostgreSQL 9.2/9.3
-                what = "pid," \
-                    "usesysid," \
-                    "usename," \
-                    "application_name," \
-                    "client_addr," \
-                    "client_hostname," \
-                    "client_port," \
-                    "backend_start," \
-                    "CAST (NULL AS xid) AS backend_xmin," \
-                    "state," \
-                    "sent_location," \
-                    "write_location," \
-                    "flush_location," \
-                    "replay_location," \
-                    "sync_priority," \
-                    "sync_state "
+                what = "pid, " \
+                    "usesysid, " \
+                    "usename, " \
+                    "application_name, " \
+                    "client_addr, " \
+                    "client_hostname, " \
+                    "client_port, " \
+                    "backend_start, " \
+                    "CAST (NULL AS xid) AS backend_xmin, " \
+                    "state, " \
+                    "sent_location AS sent_lsn, " \
+                    "write_location AS write_lsn, " \
+                    "flush_location AS flush_lsn, " \
+                    "replay_location AS replay_lsn, " \
+                    "sync_priority, " \
+                    "sync_state"
             else:
                 # PostgreSQL 9.1
-                what = "procpid AS pid," \
-                    "usesysid," \
-                    "usename," \
-                    "application_name," \
-                    "client_addr," \
-                    "client_hostname," \
-                    "client_port," \
-                    "backend_start," \
-                    "CAST (NULL AS xid) AS backend_xmin," \
-                    "state," \
-                    "sent_location," \
-                    "write_location," \
-                    "flush_location," \
-                    "replay_location," \
-                    "sync_priority," \
-                    "sync_state "
+                what = "procpid AS pid, " \
+                    "usesysid, " \
+                    "usename, " \
+                    "application_name, " \
+                    "client_addr, " \
+                    "client_hostname, " \
+                    "client_port, " \
+                    "backend_start, " \
+                    "CAST (NULL AS xid) AS backend_xmin, " \
+                    "state, " \
+                    "sent_location AS sent_lsn, " \
+                    "write_location AS write_lsn, " \
+                    "flush_location AS flush_lsn, " \
+                    "replay_location AS replay_lsn, " \
+                    "sync_priority, " \
+                    "sync_state"
 
             # Streaming client
             if client_type == self.STANDBY:
                 # Standby server
-                where = 'WHERE replay_location IS NOT NULL '
+                where = 'WHERE {replay_lsn} IS NOT NULL '.format(
+                    **self.name_map)
             elif client_type == self.WALSTREAMER:
                 # WAL streamer
-                where = 'WHERE replay_location IS NULL '
+                where = 'WHERE {replay_lsn} IS NULL '.format(
+                    **self.name_map)
             else:
                 where = ''
 
             # Execute the query
             cur.execute(
                 "SELECT %s, "
-                "pg_is_in_recovery() AS is_in_recovery,"
+                "pg_is_in_recovery() AS is_in_recovery, "
                 "CASE WHEN pg_is_in_recovery() "
-                "  THEN pg_last_xlog_receive_location() "
-                "  ELSE pg_current_xlog_location() "
-                "END AS current_location "
+                "  THEN {pg_last_wal_receive_lsn}() "
+                "  ELSE {pg_current_wal_lsn}() "
+                "END AS current_lsn "
                 "FROM pg_stat_replication r "
                 "%s"
                 "%s"
-                "ORDER BY sync_state DESC, sync_priority" % (what,
-                                                             from_repslot,
-                                                             where))
+                "ORDER BY sync_state DESC, sync_priority"
+                .format(**self.name_map)
+                % (what, from_repslot, where))
 
             # Generate a list of standby objects
             return cur.fetchall()
@@ -1326,3 +1377,53 @@ class PostgreSQLConnection(PostgreSQL):
                 names_end = len(synchronous_standby_names)
             names_list = synchronous_standby_names[names_start:names_end]
             return [x.strip() for x in names_list.split(',')]
+
+    @property
+    def name_map(self):
+        """
+        Return a map with function and directory names according to the current
+        PostgreSQL version.
+
+        Each entry has the `current` name as key and the name for the specific
+        version as value.
+
+        :rtype: dict[str]
+        """
+        # Avoid raising an error if the connection is not available
+        try:
+            server_version = self.server_version
+        except PostgresConnectionError:
+            _logger.debug('Impossible to detect the PostgreSQL version, '
+                          'name_map will return names from latest version')
+            server_version = None
+
+        if server_version and server_version < 100000:
+            return {
+                'pg_switch_wal': 'pg_switch_xlog',
+                'pg_walfile_name': 'pg_xlogfile_name',
+                'pg_wal': 'pg_xlog',
+                'pg_walfile_name_offset': 'pg_xlogfile_name_offset',
+                'pg_last_wal_replay_lsn': 'pg_last_xlog_replay_location',
+                'pg_current_wal_lsn': 'pg_current_xlog_location',
+                'pg_current_wal_insert_lsn': 'pg_current_xlog_insert_location',
+                'pg_last_wal_receive_lsn': 'pg_last_xlog_receive_location',
+                'sent_lsn': 'sent_location',
+                'write_lsn': 'write_location',
+                'flush_lsn': 'flush_location',
+                'replay_lsn': 'replay_location',
+            }
+
+        return {
+            'pg_switch_wal': 'pg_switch_wal',
+            'pg_walfile_name': 'pg_walfile_name',
+            'pg_wal': 'pg_wal',
+            'pg_walfile_name_offset': 'pg_walfile_name_offset',
+            'pg_last_wal_replay_lsn': 'pg_last_wal_replay_lsn',
+            'pg_current_wal_lsn': 'pg_current_wal_lsn',
+            'pg_current_wal_insert_lsn': 'pg_current_wal_insert_lsn',
+            'pg_last_wal_receive_lsn': 'pg_last_wal_receive_lsn',
+            'sent_lsn': 'sent_lsn',
+            'write_lsn': 'write_lsn',
+            'flush_lsn': 'flush_lsn',
+            'replay_lsn': 'replay_lsn',
+        }
