@@ -1,4 +1,4 @@
-# Copyright (C) 2011-2016 2ndQuadrant Italia Srl
+# Copyright (C) 2011-2017 2ndQuadrant Limited
 #
 # This file is part of Barman.
 #
@@ -28,6 +28,13 @@ import logging
 import logging.handlers
 import os
 import pwd
+import re
+import signal
+from contextlib import contextmanager
+
+from distutils.version import Version
+
+from barman.exceptions import TimeoutError
 
 _logger = logging.getLogger(__name__)
 
@@ -130,7 +137,7 @@ def pretty_size(size, unit=1024):
     # cast to float to avoid loosing decimals
     size = float(size)
     for suffix in suffixes:
-        if size < unit or suffix == suffixes[-1]:
+        if abs(size) < unit or suffix == suffixes[-1]:
             if suffix == suffixes[0]:
                 return "%d %s" % (size, suffix)
             else:
@@ -148,9 +155,10 @@ def human_readable_timedelta(timedelta):
     delta = abs(timedelta)
     # Calculate time units for the given interval
     time_map = {
-        'day': int(delta.days % 365),
+        'day': int(delta.days),
         'hour': int(delta.seconds / 3600),
         'minute': int(delta.seconds / 60) % 60,
+        'second': int(delta.seconds % 60),
     }
     # Build the resulting string
     time_list = []
@@ -176,13 +184,41 @@ def human_readable_timedelta(timedelta):
         else:
             time_list.append('%s minutes' % time_map['minute'])
 
+    # 'Second' part
+    if time_map['second'] > 0:
+        if time_map['second'] == 1:
+            time_list.append('%s second' % time_map['second'])
+        else:
+            time_list.append('%s seconds' % time_map['second'])
+
     human = ', '.join(time_list)
+
+    # Take care of timedelta when is shorter than a second
+    if delta < datetime.timedelta(seconds=1):
+        human = 'less than one second'
+
     # If timedelta is negative append 'ago' suffix
     if delta != timedelta:
         human += " ago"
     return human
 
 
+def total_seconds(timedelta):
+    """
+    Compatibility method because the total_seconds method has been introduced
+    in Python 2.7
+
+    :param timedelta: a timedelta object
+    :rtype: float
+    """
+    if hasattr(timedelta, 'total_seconds'):
+        return timedelta.total_seconds()
+    else:
+        return (timedelta.microseconds +
+                (timedelta.seconds + timedelta.days * 24 * 3600) * 10**6
+                ) / 10.0**6
+
+
 def which(executable, path=None):
     """
     This method is useful to find if a executable is present into the
@@ -192,9 +228,12 @@ def which(executable, path=None):
     :param str|None path: An optional search path to override the current one.
     :return str|None: the path of the executable or None
     """
-    # Get the system path and split.
+    # Get the system path if needed
     if path is None:
         path = os.getenv('PATH')
+    # If the path is None at this point we have nothing to search
+    if path is None:
+        return None
     # If executable is an absolute path, check if it exists and is executable
     # otherwise return failure.
     if os.path.isabs(executable):
@@ -202,7 +241,7 @@ def which(executable, path=None):
             return executable
         else:
             return None
-    # Search the requested executable in eery directory present in path and
+    # Search the requested executable in every directory present in path and
     # return the first occurrence that exists and is executable.
     for file_path in path.split(os.path.pathsep):
         file_path = os.path.join(file_path, executable)
@@ -242,6 +281,9 @@ class BarmanEncoder(json.JSONEncoder):
         # an unicode string
         if hasattr(obj, 'decode') and callable(obj.decode):
             return obj.decode('utf-8', 'replace')
+        # Manage (Loose|Strict)Version objects as strings.
+        if isinstance(obj, Version):
+            return str(obj)
         # Let the base class default method raise the TypeError
         return super(BarmanEncoder, self).default(obj)
 
@@ -266,7 +308,7 @@ def fsync_dir(dir_path):
 
 def simplify_version(version_string):
     """
-    Simplify a version number using a major.minor format
+    Simplify a version number by removing the patch level
 
     :param version_string: the version number to simplify
     :return str: the simplified version number
@@ -274,7 +316,14 @@ def simplify_version(version_string):
     if version_string is None:
         return None
     version = version_string.split('.')
-    return '.'.join(version[:2])
+    # If a development/beta/rc version, split out the string part
+    unreleased = re.search(r'[^0-9.]', version[-1])
+    if unreleased:
+        last_component = version.pop()
+        number = last_component[:unreleased.start()]
+        string = last_component[unreleased.start():]
+        version += [number, string]
+    return '.'.join(version[:-1])
 
 
 def with_metaclass(meta, *bases):
@@ -292,3 +341,44 @@ def with_metaclass(meta, *bases):
         def __new__(mcs, name, this_bases, d):
             return meta(name, bases, d)
     return type.__new__(Metaclass, 'temporary_class', (), {})
+
+
+@contextmanager
+def timeout(timeout_duration):
+    """
+    ContextManager responsible for timing out the contained
+    block of code after a defined time interval.
+    """
+    # Define the handler for the alarm signal
+    def handler(signum, frame):
+        raise TimeoutError()
+
+    # set the timeout handler
+    previous_handler = signal.signal(signal.SIGALRM, handler)
+    if previous_handler != signal.SIG_DFL:
+        signal.signal(signal.SIGALRM, previous_handler)
+        raise AssertionError("Another timeout is already defined")
+    # set the timeout duration
+    signal.alarm(timeout_duration)
+    try:
+        # Execute the contained block of code
+        yield
+    finally:
+        # Reset the signal
+        signal.alarm(0)
+        signal.signal(signal.SIGALRM, signal.SIG_DFL)
+
+
+def is_power_of_two(number):
+    """
+    Check if a number is a power of two or not
+    """
+
+    # This is a fast method to check for a power of two.
+    #
+    # A power of two has this structure:  100000 (one or more zeroes)
+    # This is the same number minus one:  011111 (composed by ones)
+    # This is the bitwise and:            000000
+    #
+    # This is true only for every power of two
+    return number != 0 and (number & (number-1)) == 0
